==> gcc-4.1.0.tar.bz2: gcc-4.1.0/libjava/classpath/javax/swing/plaf/basic/BasicCheckBoxUI.java <==
/* BasicCheckBoxUI.java
   Copyright (C) 2002, 2004, 2005 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package javax.swing.plaf.basic;

import javax.swing.Icon;
import javax.swing.JComponent;
import javax.swing.UIManager;
import javax.swing.plaf.ComponentUI;

public class BasicCheckBoxUI extends BasicRadioButtonUI
{  
  
  public static ComponentUI createUI(final JComponent c)  {
    return new BasicCheckBoxUI();
  }

  public Icon getDefaultIcon()
  {
    return UIManager.getIcon("CheckBox.icon");
  }
  
  /**
   * Returns the prefix for entries in the {@link UIManager} defaults table.
   *
   * @return "CheckBox."
   */
  public String getPropertyPrefix()
  {
    return "CheckBox.";
  }
}

==> gcc-4.7.2.tar.bz2: gcc-4.7.2/libjava/classpath/javax/swing/plaf/basic/BasicCheckBoxUI.java <==
/* BasicCheckBoxUI.java
   Copyright (C) 2002, 2004, 2005, 2006, Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package javax.swing.plaf.basic;

import javax.swing.JCheckBox;
import javax.swing.JComponent;
import javax.swing.UIManager;
import javax.swing.plaf.ComponentUI;

/**
 * A UI delegate for the {@link JCheckBox} component.
 */
public class BasicCheckBoxUI extends BasicRadioButtonUI
{

  /**
   * Returns a UI delegate (that is, an instance of this class) for the
   * specified component.
   *
   * @param c  the component (this should be a {@link JCheckBox}).
   *
   * @return A new instance of <code>BasicCheckBoxUI</code>.
   */
  public static ComponentUI createUI(JComponent c)
  {
    return new BasicCheckBoxUI();
  }

  /**
   * Returns the prefix for entries in the {@link UIManager} defaults table
   * (<code>"CheckBox."</code> in this case).
   *
   * @return "CheckBox."
   */
  public String getPropertyPrefix()
  {
    return "CheckBox.";
  }
}
